Set the opacity for a brain mesh from a vector of values that correspond to the vertices in the mesh.
Usage
add_opacity(mesh, a_map, a_range = c(0.5, 1), a_default = 1)Set the opacity for a brain mesh from a vector of values that correspond to the vertices in the mesh.
add_opacity(mesh, a_map, a_range = c(0.5, 1), a_default = 1)