Uses an atlas to associate the measurement results in the CIVET .dat output files with particular structures
Arguments
- atlasFile
Character path to a key to the atlas used when running civet. the key should be a comma separated file with a header and the following form
Column 1: Numeric label Column 3: Corresponding structure- dataFiles
character containing paths to .dat files of interest typically generated with civet.getAllFilenames
- civetVersion
character code for the version of civet used to generate the data files