Read in the vertex data results of a CIVET run
Arguments
- vertex_files
The data frame of vertex file names produced by civet.vertexFilenames
Read in the vertex data results of a CIVET run
The data frame of vertex file names produced by civet.vertexFilenames