For each response (voxel, vertex, or structure) compare a set of linear model formulations with the criterion of your choice (e.g. AIC, AICc, BIC).
Arguments
- object
A model or a list of models, typically mincLm, vertexLm, or anatLm results.
- ...
additional models
- metric
A function to apply to the models that extracts a result for each independent sub-model. Typical choices are AIC, AICc, and BIC. Please note that metrics are considered such that lower is better (in following AIC). To use a positive metric create a wrapper function that performs the negation, for example, to use the un-modified log-likelihood you could pass
metric = function(minc_model){ -minc_model[,"logLik"]}