linear mixed effects model applied to every item in an anatomical tree
Source:R/minc_hierarchical_anatomy.R
hanatLmer.RdSee anatLmer for more detail
Details
The volumes inside the anatomical hierarchy and the data must be of the same length and ordering.
Examples
if (FALSE) { # \dontrun{
vols <- addVolumesToHierarchy(hdefs, allvols)
hLm <- hanatLmer(~Sex + (1|ID), gf, vols)
} # }