Converts a column from a hierarchical tree into a volume for viewing or saving
Source:R/minc_hierarchical_anatomy.R
hanatToVolume.RdConverts a column from a hierarchical tree into a volume for viewing or saving
Examples
if (FALSE) { # \dontrun{
labelVol <- mincArray(mincGetVolume("some-labels.mnc"))
hLm <- hanatLm(~Sex, gfBasic, vols)
statsvol <- hanatToVolume(hLm, labelVol, "F.statistic")
mincPlotSliceSeries(anatVol, statsvol, anatLow = 700, anatHigh = 1400,
low=1, high=10, symmetric = F, begin=50, end=-50)
} # }