Creates a hierarchical anatomical tree
Source:R/minc_hierarchical_anatomy.R
makeMICeDefsHierachical.RdMakes a hierarchical tree using ontogeny from Allen Brain Institute
Details
Takes the label definitions from a CSV file (same as the rest of the anat family of functions) and places it into a tree (using data.tree). The CSV file must thus have an extra column giving the corresponding name of each structure in the Allen Institute's nomenclature.
Currently the left and right structures are leaves at the end of the tree, and so are the first to be combined into the bilateral volumes. It is possible that in the future keeping hemispheres separate will be an option.