Skip to contents

test to see whether files exist and are readable

Usage

mincFileCheck(filenames)

Arguments

filenames

paths to the files to check

Value

Returns NULL invisibly

Details

Throws an error if a file is not found or not readable