R/minc_interface.R
mincGetVector.Rd
Given a voxel coordinate, return the value at those coordinates from a set of minc files as a numeric vector
mincGetVector(filenames, v1, v2, v3, v.length = NULL)
Character vector with paths to minc files
First voxel coordinate
Second voxel coordinate
Third voxel coordinate
The number of values to return