Given a set of world coordinates return the value at those coordinates
from a set of minc files as a numeric vector
Usage
mincGetWorldVoxel(filenames, v1, v2 = NULL, v3 = NULL)
Arguments
- filenames
A character vector of one or more filenames
- v1
First world coordinate
- v2
Second world coordinate
- v3
Third world coordinate