Estimate the degrees of freedom for parameters in a mincLmer model
Source:R/minc_lmer.R
mincLmerEstimateDF.RdThere is much uncertainty in how to compute p-values for mixed-effects statistics, related to the correct calculation of the degrees of freedom of the model (see here http://glmm.wikidot.com/faq#df). mincLmer by default does not return the degrees of freedom as part of its model, instead requiring an explicit call to a separate function (such as this one). The implementation here is the Satterthwaite approximation. This approximation is computed from the data, to avoid the significant run-time requirement of computing it separate for every voxel, here it is only computed on a small number of voxels within the mask and the median DF returned for every variable.