Convert a bic_obj object to a graph for handy graph algorithms
Arguments
- bic_obj
The
bic_objobject, generated by read_obj to be converted
Convert a bic_obj object to a graph for handy graph algorithms
The bic_obj object, generated by read_obj to be converted