Add lines corresponding to the coordinates in a bic_lines object to a figure. Only draws the projection of the lines on a single dimension, no regard is given for whether the lines are near the slice of interest.
Usage
# S3 method for class 'bic_lines'
plot(x, dimension = 2, ...)Arguments
- x
an
bic_linesobject- dimension
which axis to display the lines on
- ...
additional parameters to pass to segments