R/minc_vis3D.R
read_line_obj.Rd
Parse the BIC obj format for when the object contains lines instead of a mesh.
read_line_obj(line_obj)
Path to the object file of interest
bic_lines object, which is a list of matrices, each matrix corresponds to one line in the object. The matrices are 3xN matrices of world coordinates.
bic_lines