Helper function to collate the results of a mincApplyRCPP family
(pMincApply, mcMincApply, and qMincApply) function.
Internally it calls simplify_masked and then coerces the result
to the appropriate volumetric class (e.g mincMultiDim)
Value
an object of class mincSingleDim, codemincMultiDim,
or codemincList depending on the dimensions of elements of the input
list, see simplify_masked for details.