As different versions of Civet may reflect changes in filename or directory structure, it is important that the civet.* functions be validated for each new version of Civet. This function checks whether a given Civet version number has been validated for use by these routines.
Author
Jim Nikelski nikelski@bic.mni.mcgill.ca