Given vertex data and a threshold, find the connected
component of a graph representing a bic_obj
Arguments
- obj_graph
The
igraphobject generated by obj_to_graph- data_map
A set of data corresponding to the vertices
- data_range
A two-component vector giving lower and upper bounds for vertices to include when generating connected components