Internal function to read in a table or csv file potentially with many columns and extract just the one we need
Source:R/minc_interface.R
extract_column.RdInternal function to read in a table or csv file potentially with many columns and extract just the one we need