Discrete Laplace-Beltrami operator associated with a triangle-mesh manifold
Arguments
- manifold
A list of length 2 with names 'vertex_matrix' and 'triangle_matrix' like
bic_objobject produced by read_obj- vertex_matrix
3-by-N matrix denoting the position of the N vertices defining the triangle-mesh manifold. Similar to argument
verticesin rgl::tmesh3d. Required ifmanifoldargument is not specified.- triangle_matrix
3-by-M matrix denoting the position of the M triangles defining the triangle-mesh manifold. Elements of each column are indices of vertices defining the triangle (i.e. indices are columns of the vertex_matrix). Similar to argument
indicesin rgl::tmesh3d. Required ifmanifoldargument is not specified.