Create descriptive statistics across a series of vertex files
Source:R/minc_vertex_statistics.R
vertexSummaries.RdThis function is used to compute the mean, standard deviation, sum, or variance of every vertex in a set of vertex files.
Usage
vertexMean(filenames, column = 1)
vertexSum(filenames, column = 1)
vertexVar(filenames, column = 1)
vertexSd(filenames, column = 1)Value
- out
The output will be a single vector containing as many elements as there are vertices in the input files.
Examples
if (FALSE) { # \dontrun{
# read the text file describing the dataset
gf <- read.csv("control-file.csv")
# compute the mean at every voxel of all files.
means <- vertexMean(gf$filenames)
} # }